Learn R Programming

bndesr (version 1.0.4)

query_desimbursements: Query data on loan disbursements made through the National Bank for Economic and Social Development (BNDES).

Description

Downloads the data on loan disbursements for the selected years, since 1995, and return it in the form of a dataframe.

Usage

query_desimbursements(year = "all")

Value

a dataframe with data for the selected year.

Arguments

year

selects the years which data will be downloaded. integer.

Examples

Run this code
if (FALSE) query_desimbursements(year = c(1999:2010))

Run the code above in your browser using DataLab