powered by
Downloads the data on loan disbursements for the selected years, since 1995, and return it in the form of a dataframe.
query_desimbursements(year = "all")
a dataframe with data for the selected year.
selects the years which data will be downloaded. integer.
if (FALSE) query_desimbursements(year = c(1999:2010))
Run the code above in your browser using DataLab